AppStreamElement<T> class

Tells StoreService what Operation to perform and on which item to perform the operation

Constructors

AppStreamElement({required T item, required Operation operation})

Properties

hashCode → int
The hash code for this object.
no setterinherited
item → T
final
operation → Operation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited